@@ -6,11 +6,11 @@ import (
 	"time"
 
 	log "github.com/sirupsen/logrus"
+	"k8s.io/apimachinery/pkg/api/errors"
 	"sigs.k8s.io/controller-runtime/pkg/event"
 	"sigs.k8s.io/controller-runtime/pkg/predicate"
 
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 
@@ -26,15 +26,14 @@ import (
 	ccaws "github.com/openshift/cloud-credential-operator/pkg/aws"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/metrics"
+	"github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/status"
 	secretutils "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/utils"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/utils"
+	awsutils "github.com/openshift/cloud-credential-operator/pkg/operator/utils/aws"
+	"github.com/openshift/cloud-credential-operator/pkg/util/clusteroperator"
 )
 
 const (
-	controllerName = "secretannotator"
-
-	AWSCloudCredSecretName = "aws-creds"
-
 	AwsAccessKeyName       = "aws_access_key_id"
 	AwsSecretAccessKeyName = "aws_secret_access_key"
 )
@@ -44,9 +43,12 @@ func NewReconciler(mgr manager.Manager) reconcile.Reconciler {
 	r := &ReconcileCloudCredSecret{
 		Client:           c,
 		Logger:           log.WithField("controller", constants.SecretAnnotatorControllerName),
-		AWSClientBuilder: ccaws.NewClient,
+		AWSClientBuilder: awsutils.ClientBuilder,
 	}
 
+	s := status.NewSecretStatusHandler(c)
+	clusteroperator.AddStatusHandler(s)
+
 	return r
 }
 
@@ -94,7 +96,7 @@ var _ reconcile.Reconciler = &ReconcileCloudCredSecret{}
 type ReconcileCloudCredSecret struct {
 	client.Client
 	Logger           log.FieldLogger
-	AWSClientBuilder func(accessKeyID, secretAccessKey []byte, region, infraName string) (ccaws.Client, error)
+	AWSClientBuilder func(accessKeyID, secretAccessKey []byte, c client.Client) (ccaws.Client, error)
 }
 
 // Reconcile will typically annotate the cloud cred secret to indicate the capabilities of the cred's capabilities:
@@ -112,6 +114,15 @@ func (r *ReconcileCloudCredSecret) Reconcile(request reconcile.Request) (returnR
 		metrics.MetricControllerReconcileTime.WithLabelValues(constants.SecretAnnotatorControllerName).Observe(dur.Seconds())
 	}()
 
+	defer func() {
+		if err := status.SyncOperatorStatus(r.Client); err != nil {
+			r.Logger.WithError(err).Errorf("failed to sync operator status")
+			if returnErr == nil {
+				returnErr = err
+			}
+		}
+	}()
+
 	mode, conflict, err := utils.GetOperatorConfiguration(r.Client, r.Logger)
 	if err != nil {
 		r.Logger.WithError(err).Error("error checking operator configuration")
@@ -137,7 +148,7 @@ func (r *ReconcileCloudCredSecret) Reconcile(request reconcile.Request) (returnR
 			r.Logger.Info("parent credential secret does not exist")
 			return reconcile.Result{}, nil
 		}
-		r.Logger.WithError(err).Error("failed to fetch parent credential secret")
+		r.Logger.WithError(err).Error("failed to fetch secret")
 		return reconcile.Result{}, err
 	}
 
@@ -180,15 +191,7 @@ func (r *ReconcileCloudCredSecret) validateCloudCredsSecret(secret *corev1.Secre
 		return r.updateSecretAnnotations(secret, constants.InsufficientAnnotation)
 	}
 
-	region, err := utils.LoadInfrastructureRegion(r.Client, r.Logger)
-	if err != nil {
-		return err
-	}
-	infraName, err := utils.LoadInfrastructureName(r.Client, r.Logger)
-	if err != nil {
-		return err
-	}
-	awsClient, err := r.AWSClientBuilder(accessKey, secretKey, region, infraName)
+	awsClient, err := r.AWSClientBuilder(accessKey, secretKey, r.Client)
 	if err != nil {
 		return fmt.Errorf("error creating aws client: %v", err)
 	}
@@ -206,6 +209,10 @@ func (r *ReconcileCloudCredSecret) validateCloudCredsSecret(secret *corev1.Secre
 	}
 
 	// Else, can we just pass through the current creds?
+	region, err := awsutils.LoadInfrastructureRegion(r.Client, r.Logger)
+	if err != nil {
+		return err
+	}
 	simParams := &ccaws.SimulateParams{
 		Region: region,
 	}
