@@ -21,12 +21,16 @@ import (
 	"github.com/Azure/go-autorest/autorest/azure"
 	"github.com/dgrijalva/jwt-go"
 
+	configv1 "github.com/openshift/api/config/v1"
 	operatorv1 "github.com/openshift/api/operator/v1"
 
 	"github.com/openshift/cloud-credential-operator/pkg/operator/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/metrics"
+	"github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/status"
 	secretutils "github.com/openshift/cloud-credential-operator/pkg/operator/secretannotator/utils"
 	"github.com/openshift/cloud-credential-operator/pkg/operator/utils"
+	"github.com/openshift/cloud-credential-operator/pkg/util"
+	"github.com/openshift/cloud-credential-operator/pkg/util/clusteroperator"
 
 	log "github.com/sirupsen/logrus"
 )
@@ -34,7 +38,6 @@ import (
 const (
 	controllerName = "secretannotator"
 
-	cloudCredSecretName = "azure-credentials"
 	azureClientID       = "azure_client_id"
 	azureClientSecret   = "azure_client_secret"
 	azureSubscriptionID = "azure_subscription_id"
@@ -57,6 +60,9 @@ func NewReconciler(mgr manager.Manager) reconcile.Reconciler {
 		Adal:   &adalService{},
 	}
 
+	s := status.NewSecretStatusHandler(c)
+	clusteroperator.AddStatusHandler(s)
+
 	return r
 }
 
@@ -104,6 +110,15 @@ func (r *ReconcileCloudCredSecret) Reconcile(request reconcile.Request) (returnR
 		metrics.MetricControllerReconcileTime.WithLabelValues(controllerName).Observe(dur.Seconds())
 	}()
 
+	defer func() {
+		if err := status.SyncOperatorStatus(r.Client); err != nil {
+			r.Logger.WithError(err).Errorf("failed to sync operator status")
+			if returnErr != nil {
+				returnErr = err
+			}
+		}
+	}()
+
 	mode, conflict, err := utils.GetOperatorConfiguration(r.Client, r.Logger)
 	if err != nil {
 		r.Logger.WithError(err).Error("error checking operator configuration")
@@ -207,13 +222,24 @@ func (r *ReconcileCloudCredSecret) updateSecretAnnotations(secret *corev1.Secret
 }
 
 func (r *ReconcileCloudCredSecret) checkCloudCredCreation(tenantID, clientID, secret string) (bool, error) {
-	oauthConfig, err := r.Adal.NewOAuthConfig(azure.PublicCloud.ActiveDirectoryEndpoint, tenantID)
+	infra := &configv1.Infrastructure{}
+	if err := r.Get(context.Background(), types.NamespacedName{Name: "cluster"}, infra); err != nil {
+		return false, fmt.Errorf("could not get infrastructure resource: %w", err)
+	}
+
+	cloudName := util.GetAzureCloudName(&infra.Status)
+	env, err := azure.EnvironmentFromName(string(cloudName))
+	if err != nil {
+		return false, fmt.Errorf("unable to determine Azure environment: %w", err)
+	}
+
+	oauthConfig, err := r.Adal.NewOAuthConfig(env.ActiveDirectoryEndpoint, tenantID)
 	if err != nil {
 		r.Logger.WithError(err).Error("error while creating oAuthConfig")
 		return false, err
 	}
 
-	token, err := r.Adal.NewServicePrincipalToken(*oauthConfig, clientID, secret, azure.PublicCloud.GraphEndpoint)
+	token, err := r.Adal.NewServicePrincipalToken(*oauthConfig, clientID, secret, env.GraphEndpoint)
 	if err != nil {
 		r.Logger.WithError(err).Error("error while creating service principal")
 		return false, err
